"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.apiRequestAllItems = exports.apiRequest = void 0;
const n8n_workflow_1 = require("n8n-workflow");
async function apiRequest(method, endpoint, body, query, uri, option = {}) {
    const credentials = this.getCredentials('baserowApi');
    const host = this.getNodeParameter('host', 0);
    if (credentials === undefined) {
        throw new n8n_workflow_1.NodeOperationError(this.getNode(), 'No credentials got returned!');
    }
    query = query || {};
    const options = {
        headers: {
            authorization: `Token ${credentials.apiToken}`,
        },
        method,
        body,
        qs: query,
        uri: uri || `${host}${endpoint}`,
        useQuerystring: false,
        json: true,
    };
    if (Object.keys(option).length !== 0) {
        Object.assign(options, option);
    }
    if (Object.keys(body).length === 0) {
        delete options.body;
    }
    try {
        return await this.helpers.request(options);
    }
    catch (error) {
        throw new n8n_workflow_1.NodeApiError(this.getNode(), error);
    }
}
exports.apiRequest = apiRequest;
async function apiRequestAllItems(method, endpoint, body, query, limit = 0) {
    if (query === undefined) {
        query = {};
    }
    query.size = query.size || 100;
    query.page = 1;
    let remaining = limit;
    const returnData = [];
    let responseData;
    do {
        responseData = await apiRequest.call(this, method, endpoint, body, query);
        if (limit > 0) {
            if (responseData.results.length > remaining) {
                responseData.results = responseData.results.slice(0, remaining);
            }
            remaining -= responseData.results.length;
        }
        returnData.push.apply(returnData, responseData.results);
        query.page += 1;
    } while (responseData.next !== undefined && remaining > 0);
    return returnData;
}
exports.apiRequestAllItems = apiRequestAllItems;
//# sourceMappingURL=GenericFunctions.js.map